@@ -3,9 +3,11 @@ class TestRunInfo(object):
         self.reset()
 
     def reset(self):
-        self.runTestIds = []
+        self.runTestIds = []  # The ids here will all be unique.
+        self.runCount = (
+            0
+        )  # The count here will be the actually test run, including potential duplicated.
         self.failedTestId = None
-        self.runCount = 0
         self.successCount = 0
         self.failedCount = 0
         self.errorCount = 0
@@ -17,4 +19,4 @@ class TestRunInfo(object):
         self.sessionRunTime = 0
 
         self._testStartTimes = {}
-        self.singleTestRunTime = 0
\ No newline at end of file
+        self.singleTestRunTime = 0
