@@ -3,7 +3,7 @@ import logging
 from iutest import dcc
 from iutest import _version
 from iutest.core import importutils
-from iutest.qt import QtCore, QtWidgets, iconFromPath, variantToPyValue
+from iutest.qt import QtCore, QtGui, QtWidgets, iconFromPath, variantToPyValue
 from iutest.core import iconutils
 from iutest.core import appsettings
 from iutest.core import constants
@@ -15,6 +15,7 @@ from iutest.ui import unittesttree
 from iutest.ui import statuslabel
 from iutest.ui import uiutils
 from iutest.ui import configwindow
+from iutest.ui import inlinebuttonlineedit as btnLineEdit
 
 logger = logging.getLogger(__name__)
 
@@ -23,8 +24,6 @@ class IUTestWindow(QtWidgets.QWidget):
     _iutestIcon = None
     _reimportIcon = None
     _reloadUiIcon = None
-    _clearIcon = None
-    _moreIcon = None
     _filterIcon = None
     _autoFilterIcon = None
     _resetIcon = None
@@ -32,11 +31,14 @@ class IUTestWindow(QtWidgets.QWidget):
     _clearLogIcon = None
     _stopAtErrorIcon = None
     _configIcon = None
+    _caseSensitiveIcon = None
+    _wholeWordIcon = None
     _panelStateIconSet = None
 
     def __init__(self, startDirOrModule=None, topDir=None, parent=None):
         parent = parent or dcc.findParentWindow()
         QtWidgets.QWidget.__init__(self, parent)
+        self._uiStream = uistream.UiStream()
 
         self._initIcons()
 
@@ -66,6 +68,7 @@ class IUTestWindow(QtWidgets.QWidget):
         self._view.runTests.connect(self._runTests)
         self._view.runSetupOnly.connect(self._runTestSetupOnly)
         self._view.runWithoutTearDown.connect(self._runTestWithoutTearDown)
+        self._view.searchNeeded.connect(self._prepareTreeSearch)
         self._view.itemSelectionChanged.connect(self._viewSelectionChanged)
 
         leftLay.addWidget(self._view)
@@ -73,10 +76,11 @@ class IUTestWindow(QtWidgets.QWidget):
         # right layout -----------------------------------
         self._rightWidget, rightLay = self._createSplitterContent()
         _logTopLayout = uiutils.makeMinorHorizontalLayout()
-        self._logWgt = logbrowser.LogBrowser(self)
-        self._makeLogTopLayout(_logTopLayout)
+        self._logBrowser = logbrowser.LogBrowser(self)
+        self._logBrowser.searchNeeded.connect(self._prepareLogSearch)
+        self._makeLogBrowserTopWidgets(_logTopLayout)
         rightLay.addLayout(_logTopLayout, 0)
-        rightLay.addWidget(self._logWgt, 1)
+        rightLay.addWidget(self._logBrowser, 1)
 
         self._splitter.setSizes([230, 500])
         self._splitter.setStretchFactor(0, 0)
@@ -92,9 +96,9 @@ class IUTestWindow(QtWidgets.QWidget):
 
         self.resize(QtCore.QSize(900, 500))
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose, True)  # for reimport convenience.
-        self.setTabOrder(self._rootDirLE, self._searchLE)
-        self.setTabOrder(self._searchLE, self._view)
-        self.setTabOrder(self._view, self._logWgt)
+        self.setTabOrder(self._rootDirLE, self._treeFilterLE)
+        self.setTabOrder(self._treeFilterLE, self._view)
+        self.setTabOrder(self._view, self._logBrowser)
         self.setWindowIcon(self._iutestIcon)
         self.setWindowFlags(QtCore.Qt.Window)
 
@@ -107,7 +111,7 @@ class IUTestWindow(QtWidgets.QWidget):
         QtCore.QTimer.singleShot(0, self._initialLoad)
 
     def getLogBrowserWidget(self):
-        return self._logWgt
+        return self._logBrowser
 
     def resetUiTestManager(self):
         self._view.setTestManager(self._testManager)
@@ -124,18 +128,68 @@ class IUTestWindow(QtWidgets.QWidget):
         splitterLay.setContentsMargins(0, 0, 0, 0)
         self._splitter.addWidget(wgt)
         return wgt, splitterLay
+    
+    def _prepareLogSearch(self, txt):
+        if txt:
+            self._logSearchLE.setText(txt)
+        
+        self._logSearchLE.selectAll()
+        self._logSearchLE.setFocus()
+    
+    def _prepareTreeSearch(self):
+        self._treeFilterLE.selectAll()
+        self._treeFilterLE.setFocus()
 
-    def _makeLogTopLayout(self, layout):
+    def _makeLogBrowserTopWidgets(self, layout):
         _console = QtWidgets.QLabel("Log Browser")
 
+        self._logSearchLE = btnLineEdit.InlineButtonLineEdit(withClearButton=True, parent=self)
+        self._logSearchLE.setToolTip(
+            "Enter to search next keyword in the log browser, ctrl+Enter to search backward."
+        )
+        self._logSearchLE.setPlaceholderText("Input to search")
+        self._logSearchLE.returnPressed.connect(self._applyLoggingSearchText)
+
+        self._wholeWordBtn = uiutils.makeIconButton(self._wholeWordIcon)
+        self._wholeWordBtn.setCheckable(True)
+        self._logSearchLE.addButton("wholeWord", self._wholeWordBtn)
+
+        self._sensitiveBtn = uiutils.makeIconButton(self._caseSensitiveIcon)
+        self._sensitiveBtn.setCheckable(True)
+        self._logSearchLE.addButton("caseSensitive", self._sensitiveBtn)
+
         self._clearLogBtn = uiutils.makeIconButton(self._clearLogIcon, self)
         self._clearLogBtn.setToolTip("Clear the log browser logging.")
-        self._clearLogBtn.clicked.connect(self._logWgt.clear)
+        self._clearLogBtn.clicked.connect(self._logBrowser.clear)
 
         layout.addWidget(_console, 0)
         layout.addStretch(1)
+        layout.addWidget(self._logSearchLE, 0)
         layout.addWidget(self._clearLogBtn, 0)
 
+    def _applyLoggingSearchText(self):
+        keyword = str(self._logSearchLE.text())
+        if not keyword:
+            return
+
+        ctrl = bool(QtWidgets.QApplication.keyboardModifiers() & QtCore.Qt.ControlModifier)
+        flag = QtGui.QTextDocument.FindFlags()
+        if self._wholeWordBtn.isChecked():
+            flag = flag | QtGui.QTextDocument.FindWholeWords
+        if self._sensitiveBtn.isChecked():
+            flag = flag | QtGui.QTextDocument.FindCaseSensitively
+        if ctrl:
+            flag = flag | QtGui.QTextDocument.FindBackward
+
+        found = self._logBrowser.find(keyword, flag)
+        if found:
+            return
+        if not ctrl:
+            self._logBrowser.moveCursor(QtGui.QTextCursor.Start)
+        else:
+            self._logBrowser.moveCursor(QtGui.QTextCursor.End)
+        self._logBrowser.find(keyword, flag)
+
     @classmethod
     def _initSingleIcon(cls, iconVarName, iconFileName):
         iconPath = iconutils.iconPath(iconFileName)
@@ -152,17 +206,18 @@ class IUTestWindow(QtWidgets.QWidget):
         cls._panelStateIconSet = [iconFromPath(p) for p in panelStatePaths]
 
         iconutils.initSingleClassIcon(cls, "_iutestIcon", "iutest.svg")
-        iconutils.initSingleClassIcon(cls,"_reimportIcon", "reimport.svg")
-        iconutils.initSingleClassIcon(cls,"_reloadUiIcon", "reloadUI.svg")
-        iconutils.initSingleClassIcon(cls,"_configIcon", "config.svg")
-        iconutils.initSingleClassIcon(cls,"_clearIcon", "clear.svg")
-        iconutils.initSingleClassIcon(cls,"_moreIcon", "more.svg")
-        iconutils.initSingleClassIcon(cls,"_filterIcon", "stateFilter.svg")
-        iconutils.initSingleClassIcon(cls,"_autoFilterIcon", "autoFilter.svg")
-        iconutils.initSingleClassIcon(cls,"_resetIcon", "reset.svg")
-        iconutils.initSingleClassIcon(cls,"_clearLogIcon", "clearLog.svg")
-        iconutils.initSingleClassIcon(cls,"_clearLogOnRunIcon", "clearLogOnRun.svg")
-        iconutils.initSingleClassIcon(cls,"_stopAtErrorIcon", "stopAtError.svg")
+        iconutils.initSingleClassIcon(cls, "_reimportIcon", "reimport.svg")
+        iconutils.initSingleClassIcon(cls, "_reloadUiIcon", "reloadUI.svg")
+        iconutils.initSingleClassIcon(cls, "_configIcon", "config.svg")
+        iconutils.initSingleClassIcon(cls, "_moreIcon", "more.svg")
+        iconutils.initSingleClassIcon(cls, "_filterIcon", "stateFilter.svg")
+        iconutils.initSingleClassIcon(cls, "_autoFilterIcon", "autoFilter.svg")
+        iconutils.initSingleClassIcon(cls, "_resetIcon", "reset.svg")
+        iconutils.initSingleClassIcon(cls, "_clearLogIcon", "clearLog.svg")
+        iconutils.initSingleClassIcon(cls, "_clearLogOnRunIcon", "clearLogOnRun.svg")
+        iconutils.initSingleClassIcon(cls, "_stopAtErrorIcon", "stopAtError.svg")
+        iconutils.initSingleClassIcon(cls, "_caseSensitiveIcon", "caseSensitive.svg")
+        iconutils.initSingleClassIcon(cls, "_wholeWordIcon", "wholeWord.svg")
 
     def _addToggleConfigAction(self, lbl, icon, tooltip, configKey, slot):
         # Cannot use self._configMenu.addAction() directly here since over-zealous garbage collection in some DCC apps:
@@ -176,28 +231,6 @@ class IUTestWindow(QtWidgets.QWidget):
         self._configMenu.addAction(act)
         return (act, value)
 
-    def _regenerateBrowseMenu(self):
-        self._browseMenu.clear()
-
-        act = self._browseMenu.addAction("Pick Test Root Dir ...")
-        act.triggered.connect(self._onBrowseTestsRootDir)
-        act = self._browseMenu.addAction("Pick Top Root Dir ...")
-        act.triggered.connect(self._onBrowseTopDir)
-        self._browseMenu.addSeparator()
-        act = self._browseMenu.addAction("Save Current Path Settings ...")
-        act.triggered.connect(self._onSaveCurrentDirSettings)
-        act = self._browseMenu.addAction("Delete Current Settings ...")
-        act.triggered.connect(self._onDeleteCurrentDirSettings)
-        self._browseMenu.addSeparator()
-
-        # Read settings:
-        config = appsettings.get().testDirSettings()
-        for key, pair in config.items():
-            act = self._browseMenu.addAction(key)
-            act.triggered.connect(self._loadSavedDirPair)
-            act.setToolTip("\n".join(pair))
-        self._browseMenu.addSeparator()
-
     def _updateLabelOfTestRunnerAct(self, act, currentMode):
         runnerMode = variantToPyValue(act.data())
         runner = self._testManager.getRunnerByMode(runnerMode)
@@ -207,14 +240,16 @@ class IUTestWindow(QtWidgets.QWidget):
 
     def _updateConfigButton(self, runner):
         self._runnerConfigBtn.setIcon(runner.icon())
-        self._runnerConfigBtn.setToolTip("Test Runner: {}, click for more settings.".format(runner.name()))
+        self._runnerConfigBtn.setToolTip(
+            "Test Runner: {}, click for more settings.".format(runner.name())
+        )
 
     def _makeRunnerConfigButton(self):
         currentRunner = self._setInitialTestMode()
         currentRunnerMode = currentRunner.mode()
-        self._runnerConfigBtn, self._configMenu = self._makeMenuToolButton()
+        self._runnerConfigBtn, self._configMenu = uiutils.makeMenuToolButton(parent=self)
         self._updateConfigButton(currentRunner)
-        
+
         for runner in self._testManager.iterAllRunners():
             icon = runner.icon()
             toolTip = "Run tests using {}.".format(runner.name())
@@ -237,7 +272,7 @@ class IUTestWindow(QtWidgets.QWidget):
             self._stopAtErrorIcon,
             "Stop the tests running once it encounters a test error/failure.",
             configKey=constants.CONFIG_KEY_STOP_ON_ERROR,
-            slot=self._onStopOnErrorActionToggled
+            slot=self._onStopOnErrorActionToggled,
         )
         self._testManager.setStopOnError(stopOnError)
 
@@ -247,7 +282,7 @@ class IUTestWindow(QtWidgets.QWidget):
             self._autoFilterIcon,
             "Apply a ':ran' filter automatically after every test run so that only the run tests shown in the view.",
             configKey=constants.CONFIG_KEY_AUTO_FILTERING_STATE,
-            slot=self._onAutoFilterActionToggled
+            slot=self._onAutoFilterActionToggled,
         )
 
         # auto clear log on run act:
@@ -256,7 +291,7 @@ class IUTestWindow(QtWidgets.QWidget):
             self._clearLogOnRunIcon,
             "Clear the log browser automatically before every test run.",
             configKey=constants.CONFIG_KEY_AUTO_CLEAR_LOG_STATE,
-            slot=self._onAutoClearLogActionToggled
+            slot=self._onAutoClearLogActionToggled,
         )
 
         self._configMenu.addSeparator()
@@ -267,25 +302,13 @@ class IUTestWindow(QtWidgets.QWidget):
     def _showConfigWindow(self):
         configwindow.ConfigWindow.show(self)
 
-    def _makeMenuToolButton(self, icon=None, toolTip=""):
-        btn = QtWidgets.QToolButton(self)
-        if icon:
-            btn.setIcon(icon)
-        btn.setToolTip(toolTip)
-        btn.setContentsMargins(0,0,0,0)
-        btn.setIconSize(QtCore.QSize(20,20))
-        btn.setPopupMode(btn.InstantPopup)
-        menu = QtWidgets.QMenu(btn)
-        btn.setMenu(menu)
-        return (btn, menu)
-
     def _setInitialTestMode(self):
         initRunnerMode = appsettings.get().simpleConfigIntValue(
             constants.CONFIG_KEY_LAST_RUNNER_MODE, -1
         )
         if initRunnerMode < 0:
             initRunnerMode = self._testManager.getFeasibleRunnerMode()
-            
+
         self._testManager.setRunnerMode(initRunnerMode)
         return self._testManager.getRunner()
 
@@ -296,11 +319,11 @@ class IUTestWindow(QtWidgets.QWidget):
         )
         self._rootDirLE = rootpathedit.RootPathEdit(self)
         self._rootDirLE.rootPathChanged.connect(self._switchToTestRootPath)
-
-        self._browseBtn, self._browseMenu = self._makeMenuToolButton(
-            self._moreIcon, "Click to access more features."
-        )
-        self._regenerateBrowseMenu()
+        self._rootDirLE.rootDirPicked.connect(self._onBrowseTestsRootDir)
+        self._rootDirLE.topDirPicked.connect(self._onBrowseTopDir)
+        self._rootDirLE.saveCurrentDirSettings.connect(self._onSaveCurrentDirSettings)
+        self._rootDirLE.loadSavedDirPair.connect(self._loadSavedDirPair)
+        self._rootDirLE.deleteCurrentDirSettings.connect(self._onDeleteCurrentDirSettings)
 
         self._panelVisBtn = uiutils.makeIconButton(self._panelStateIconSet[-1], self)
         self._panelVisBtn.setToolTip(
@@ -311,7 +334,6 @@ class IUTestWindow(QtWidgets.QWidget):
 
         self._dirLayout.addWidget(lbl)
         self._dirLayout.addWidget(self._rootDirLE)
-        self._dirLayout.addWidget(self._browseBtn)
         self._dirLayout.addWidget(self._panelVisBtn)
         self._dirLayout.addWidget(self._runnerConfigBtn)
 
@@ -329,24 +351,18 @@ class IUTestWindow(QtWidgets.QWidget):
         reloadUIBtn.clicked.connect(self._onReloadUiButtonClicked)
         layout.addWidget(reloadUIBtn)
 
-        self._searchLE = QtWidgets.QLineEdit()
-        self._searchLE.setToolTip(
+        self._treeFilterLE = btnLineEdit.InlineButtonLineEdit(withClearButton=True, parent=self)
+        self._treeFilterLE.setToolTip(
             "Input keywords to filter the tests, separated by space.\n"
             "For normal keyword, the match operation is 'AND'\n"
             "For state keyword starting with ':', the match operation is 'OR'."
         )
-        self._searchLE.setPlaceholderText("Input to filter")
-        self._searchLE.textChanged.connect(self._applyFilterText)
-        layout.addWidget(self._searchLE)
+        self._treeFilterLE.setPlaceholderText("Input to filter")
+        self._treeFilterLE.textChanged.connect(self._applyTreeFilterText)
+        layout.addWidget(self._treeFilterLE)
 
-        self._clearFilterBtn = uiutils.makeIconButton(self._clearIcon, self)
-        self._clearFilterBtn.setToolTip("Clear all filters.")
-        self._clearFilterBtn.setEnabled(False)
-        self._clearFilterBtn.clicked.connect(self._clearFilter)
-        layout.addWidget(self._clearFilterBtn)
-
-        self._filterBtn, self._filterMenu = self._makeMenuToolButton(
-            self._filterIcon, "Click to apply more predefined filters."
+        self._filterBtn, self._filterMenu = uiutils.makeMenuToolButton(
+            self._filterIcon, "Click to apply more predefined filters.", self
         )
         for lbl in constants.KEYWORD_TEST_STATES:
             act = self._filterMenu.addAction(lbl)
@@ -372,8 +388,11 @@ class IUTestWindow(QtWidgets.QWidget):
         self._testManager.setRunnerMode(runnerMode)
         runner = self._testManager.getRunner()
         self._updateConfigButton(runner)
-        logger.info("Switch to %s for test running.", runner.name())
-        
+
+        self._uiStream.write(
+            ">> Switch to unittest runner <b>{}</b>.<br>".format(runner.name())
+        )
+
         self._onReloadUiButtonClicked()
         appsettings.get().saveSimpleConfig(
             constants.CONFIG_KEY_LAST_RUNNER_MODE, runnerMode
@@ -448,15 +467,15 @@ class IUTestWindow(QtWidgets.QWidget):
 
     def _addStateFilter(self):
         stateKeyword = str(self.sender().text())
-        search = str(self._searchLE.text()).strip()
+        search = str(self._treeFilterLE.text()).strip()
         if not search:
-            self._searchLE.setText(stateKeyword)
+            self._treeFilterLE.setText(stateKeyword)
             return
         parts = search.split(" ")
         if stateKeyword in parts:
             return
         parts.insert(0, stateKeyword)
-        self._searchLE.setText(" ".join(parts))
+        self._treeFilterLE.setText(" ".join(parts))
 
     def _saveLastTestDir(self, startDir, topDir):
         settings = appsettings.get()
@@ -466,24 +485,20 @@ class IUTestWindow(QtWidgets.QWidget):
         settings.saveSimpleConfig(constants.CONFIG_KEY_LAST_TOP_DIR, topDir, sync=True)
         logger.info("Save the last test root: %s", startDir)
 
-    def _loadSavedDirPair(self):
-        act = self.sender()
-        _topDir, _startDirOrModule = act.toolTip().split("\n")
+    def _loadSavedDirPair(self, _startDirOrModule, _topDir, configName):
         self._testManager.setTopDir(_topDir)
         self._testManager.setStartDirOrModule(_startDirOrModule)
-
-        configName = str(act.text())
         self._saveLastTestDir(_startDirOrModule, _topDir)
         self._updateWindowTitle(configName)
         self._updateDirUI()
-        self._searchLE.clear()
+        self._treeFilterLE.clear()
         self.reload()
 
     def _switchToTestRootPath(self, startDir, topDir):
         self._testManager.setDirs(startDir, topDir)
         self._updateWindowTitle(startDir)
         self._updateDirUI()
-        self._searchLE.clear()
+        self._treeFilterLE.clear()
         self.reload(keepUiStates=False)
         if not self._testManager.hasLastListerError():
             self._saveLastTestDir(startDir, topDir)
@@ -519,32 +534,30 @@ class IUTestWindow(QtWidgets.QWidget):
         self._rootDirLE.setText(self._testManager.startDirOrModule())
         self._rootDirLE.setToolTip(self._testManager.topDir())
 
-    def _onBrowseTestsRootDir(self):
-        dirPath = QtWidgets.QFileDialog.getExistingDirectory(
-            self, "Pick the Test Root Directory"
-        )
-        if dirPath:
-            self._testManager.setStartDirOrModule(dirPath)
-            self._updateDirUI()
-            self._searchLE.clear()
-            self.reload()
+    def _onBrowseTestsRootDir(self, dirPath):
+        self._testManager.setStartDirOrModule(dirPath)
+        self._updateDirUI()
+        self._treeFilterLE.clear()
+        self.reload()
 
-    def _onBrowseTopDir(self):
-        dirPath = QtWidgets.QFileDialog.getExistingDirectory(
-            self, "Pick the Top Python Directory"
-        )
-        if dirPath:
-            self._testManager.setTopDir(dirPath)
+    def _onBrowseTopDir(self, dirPath):
+        self._testManager.setTopDir(dirPath)
 
-        self._searchLE.clear()
+        self._treeFilterLE.clear()
         self._updateDirUI()
         self.reload()
 
     def _updateWindowTitle(self, configName=None):
         if configName:
-            self.setWindowTitle("{} {} - {}".format(constants.APP_NAME, _version.__version__, configName))
+            self.setWindowTitle(
+                "{} {} - {}".format(
+                    constants.APP_NAME, _version.__version__, configName
+                )
+            )
         else:
-            self.setWindowTitle("{} {}".format(constants.APP_NAME, _version.__version__))
+            self.setWindowTitle(
+                "{} {}".format(constants.APP_NAME, _version.__version__)
+            )
 
     def _configNameFromStartAndTopDir(self, startDir, topDir):
         config = appsettings.get().testDirSettings()
@@ -594,7 +607,7 @@ class IUTestWindow(QtWidgets.QWidget):
         self._updateWindowTitle(name[0])
 
     def _deferredRegenerateMenu(self):
-        QtCore.QTimer.singleShot(0, self._regenerateBrowseMenu)
+        QtCore.QTimer.singleShot(0, self._rootDirLE.regenerateBrowseMenu)
 
     def _onDeleteCurrentDirSettings(self):
         config = appsettings.get().testDirSettings()
@@ -624,7 +637,7 @@ class IUTestWindow(QtWidgets.QWidget):
 
     def _runAllTests(self):
         self._view.resetAllItemsToNormal()
-        self._searchLE.clear()
+        self._treeFilterLE.clear()
         self._testManager.runAllTests()
         self._updateReimportRerunButtonEnabled()
 
@@ -672,9 +685,6 @@ class IUTestWindow(QtWidgets.QWidget):
         self._testManager.runSingleTestPartially(testId, partialMode)
         self._updateReimportRerunButtonEnabled()
 
-    def _clearFilter(self):
-        self._searchLE.clear()
-
     def reload(self, keepUiStates=True):
         self._beforeTestCollection()
         with uistream.LogCaptureContext():  # Report the possible error report to UI as well:
@@ -688,13 +698,13 @@ class IUTestWindow(QtWidgets.QWidget):
         self._statusLbl.reportTestCount(self._view.testCount())
 
     def _applyCurrentFilter(self, removeStateFilters=True, keepUiStates=True):
-        searchText = str(self._searchLE.text())
+        searchText = str(self._treeFilterLE.text())
         if removeStateFilters:
             keywords = searchText.split(" ")
             filterFunc = lambda x: not x.startswith(":")
             keywords = filter(filterFunc, keywords)
             searchText = " ".join(keywords)
-            self._searchLE.setText(searchText)
+            self._treeFilterLE.setText(searchText)
 
         self._applyFilterTextWithState(searchText, keepUiStates=keepUiStates)
 
@@ -716,15 +726,14 @@ class IUTestWindow(QtWidgets.QWidget):
         self._hookUiToStream()
         self._view.resetTestItemsById(tests)
 
-    def _applyFilterText(self, txt):
+    def _applyTreeFilterText(self, txt):
         self._applyFilterTextWithState(str(txt), keepUiStates=False)
 
     def _applyFilterTextWithState(self, txt, keepUiStates=True):
         lowerTxt = txt.strip().lower()
         keywords = lowerTxt.split(" ")
-        self._clearFilterBtn.setEnabled(bool(keywords))
         self._view.setFilterKeywords(keywords, ensureFirstMatchVisible=not keepUiStates)
-    
+
     def closeEvent(self, event):
         uistream.UiStream.unsetUi(self)
         QtWidgets.QWidget.closeEvent(self, event)
@@ -744,13 +753,13 @@ class IUTestWindow(QtWidgets.QWidget):
     def onTestRunningSessionStart(self):
         self._statusLbl.setText("Running tests...")
         if self._clearLogOnRunAct.isChecked():
-            self._logWgt.clear()
-        self._logWgt.logSeparator()
+            self._logBrowser.clear()
+        self._logBrowser.logSeparator()
 
     def onAllTestsFinished(self):
         self._view.onAllTestsFinished()
         if self._autoFilterAct.isChecked():
-            self._searchLE.setText(constants.KEYWORD_TEST_STATE_RUN)
+            self._treeFilterLE.setText(constants.KEYWORD_TEST_STATE_RUN)
         self._statusLbl.updateReport()
 
     def repaintUi(self):
