@@ -1,11 +1,22 @@
+from iutest.qt import QtCore, QtGui, QtWidgets, Signal
 from iutest.core import gotocode
 from iutest.ui import uiconstants
-from iutest.qt import QtGui, QtWidgets
+from iutest.ui import uiutils
+from iutest.ui import scrollareapan
 
 
 class LogBrowser(QtWidgets.QTextBrowser):
+    searchNeeded = Signal(str)
+
     def __init__(self, parent=None):
         QtWidgets.QTextBrowser.__init__(self, parent)
+        self._pan = scrollareapan.ScrollAreaPan(self, 1.0)
+        self._pan.installEventFilterOn(self.viewport())
+        self._codeVisitor = gotocode.CodeLineVisitor(self)
+        self._codeVisitor.errorIssued.connect(self._onGoToCodeError)
+        self._setupUi()
+
+    def _setupUi(self):
         fn = self.font()
         pixelSize = max(12, fn.pixelSize() + 2)
         fn.setPixelSize(pixelSize)
@@ -15,8 +26,8 @@ class LogBrowser(QtWidgets.QTextBrowser):
         self.setWordWrapMode(QtGui.QTextOption.NoWrap)
         self.setOpenLinks(False)
         self.anchorClicked.connect(self.onLinkClicked)
+        self.setToolTip("The test logging browser, use <b>MMB</b> to pan around.")
         self._initCSS()
-        self._codeVisitor = gotocode.CodeLineVisitor(self)
 
     def _initCSS(self):
         css = """
@@ -66,3 +77,16 @@ class LogBrowser(QtWidgets.QTextBrowser):
 
     def logWarning(self, msg, *args):
         self.logWithColor(msg, uiconstants.LOG_COLOR_WARNING, *args)
+
+    def _onGoToCodeError(self, msg):
+        uiutils.popUpMessageOnCursorPos(msg, self)
+
+    def keyPressEvent(self, event):
+        key = event.key()
+        ctrl = bool(event.modifiers() & QtCore.Qt.ControlModifier)
+        if ctrl and key == QtCore.Qt.Key_F:
+            self.searchNeeded.emit(str(self.textCursor().selectedText()))
+            event.accept()
+            return
+
+        QtWidgets.QTextBrowser.keyPressEvent(self, event)
