@@ -1,4 +1,4 @@
-from iutest.qt import QtCore, QtWidgets
+from iutest.qt import QtCore, QtGui, QtWidgets
 
 
 def makeMainLayout(hostWidget=None):
@@ -32,6 +32,19 @@ def makeIconButton(icon, parent=None):
     return btn
 
 
+def makeMenuToolButton(icon=None, toolTip="", parent=None):
+    btn = QtWidgets.QToolButton(parent)
+    if icon:
+        btn.setIcon(icon)
+    btn.setToolTip(toolTip)
+    btn.setContentsMargins(0, 0, 0, 0)
+    btn.setIconSize(QtCore.QSize(20, 20))
+    btn.setPopupMode(btn.InstantPopup)
+    menu = QtWidgets.QMenu(btn)
+    btn.setMenu(menu)
+    return (btn, menu)
+
+
 def addSeparatorToLayout(layout, direction):
     sep = QtWidgets.QFrame()
     sep.setStyleSheet("color:black")
@@ -45,3 +58,8 @@ def addSeparatorToLayout(layout, direction):
 
     sep.setLineWidth(1)
     layout.addWidget(sep)
+
+
+def popUpMessageOnCursorPos(msg, bgWidget=None):
+    gpos = QtGui.QCursor.pos()
+    QtWidgets.QWhatsThis.showText(gpos, msg, bgWidget)
