@@ -8,6 +8,8 @@ from iutest.core import gotocode
 from iutest.core import importutils
 from iutest.core import loggingutils
 from iutest.core import uistream
+from iutest.ui import uiutils
+from iutest.ui import scrollareapan
 
 logger = logging.getLogger(__name__)
 
@@ -60,6 +62,7 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
     runTests = Signal(tuple)
     runSetupOnly = Signal(str)
     runWithoutTearDown = Signal(str)
+    searchNeeded = Signal()
 
     _testAllIcons = []
     _testPackageIcons = []
@@ -84,8 +87,14 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
 
     def __init__(self, parent):
         QtWidgets.QTreeWidget.__init__(self, parent)
+        self._pan = scrollareapan.ScrollAreaPan(
+            self, 
+            scrollFactor=0.05
+        )
+        self._pan.installEventFilterOn(self.viewport())
         self._uiStream = uistream.UiStream()
         self._codeVisitor = gotocode.CodeLineVisitor(self)
+        self._codeVisitor.errorIssued.connect(self._onGoToCodeError)
 
         self.setItemDelegate(self._TreeItemDelegate(self))
         self.setTextElideMode(QtCore.Qt.ElideLeft)
@@ -110,7 +119,8 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
         self._makeContextMenu()
 
         self.setToolTip(
-            "This view lists out the tests, <b>double click</b> on them to run them, <b>Ctrl+C</b> to copy the python module path."
+            "This view lists out the tests, <b>Double Click</b> on them to run them, <b>Ctrl+C</b> to copy the python module path;" + \
+            "<br><br><b>MMB Dragging</b> to pan the view around."
         )
 
     def setTestManager(self, manager):
@@ -154,9 +164,13 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
             if self._categoryOfItem(item) != constants.ITEM_CATEGORY_PACKAGE:
                 testIds.append(self.testIdOfItem(item))
                 continue
-            
-            splittedTests = [self.testIdOfItem(item) for item in \
-                self._iterAllDescendentItem(item, constants.ITEM_CATEGORY_MODULE)]
+
+            splittedTests = [
+                self.testIdOfItem(item)
+                for item in self._iterAllDescendentItem(
+                    item, constants.ITEM_CATEGORY_MODULE
+                )
+            ]
             testIds.extend(splittedTests)
         return tuple(testIds)
 
@@ -192,12 +206,17 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
             cls._testSuiteIcons,
             cls._testCaseIcons,
         )
-        iconutils.initSingleClassIcon(cls,"_reimportAndRunIcon", "reimportAndRerun.svg")
-        iconutils.initSingleClassIcon(cls,"_runPartialIcon", "run_partial.svg")
-        iconutils.initSingleClassIcon(cls,"_runAllIcon", "runAll.svg")
-        iconutils.initSingleClassIcon(cls,"_runSelectedIcon", "runSelected.svg")
+        iconutils.initSingleClassIcon(
+            cls, "_reimportAndRunIcon", "reimportAndRerun.svg"
+        )
+        iconutils.initSingleClassIcon(cls, "_runPartialIcon", "run_partial.svg")
+        iconutils.initSingleClassIcon(cls, "_runAllIcon", "runAll.svg")
+        iconutils.initSingleClassIcon(cls, "_runSelectedIcon", "runSelected.svg")
 
     def setFilterKeywords(self, keywords, ensureFirstMatchVisible=False):
+        if not self._rootTestItem:
+            return
+
         itemStates = {}
         if keywords:
             itemToFocus = None
@@ -356,7 +375,7 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
         for i in range(item.childCount()):
             cState = variantToPyValue(item.child(i).data(0, QtCore.Qt.UserRole + 1))
             stateToSet = max(stateToSet, cState)
-        
+
         self._setItemIconState(item, stateToSet)
 
         if item is self._rootTestItem:
@@ -390,13 +409,18 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
             logger.info("No item selected to copy the module path.")
 
     def keyPressEvent(self, event):
-        if event.key() == QtCore.Qt.Key_C and (
-            event.modifiers() & QtCore.Qt.ControlModifier
-        ):
+        ctrl = bool(event.modifiers() & QtCore.Qt.ControlModifier)
+        key = event.key()
+        if ctrl and key == QtCore.Qt.Key_C:
             self.copyFirstSelectedTestId()
             event.accept()
             return
 
+        if ctrl and key == QtCore.Qt.Key_F:
+            self.searchNeeded.emit()
+            event.accept()
+            return
+
         QtWidgets.QTreeWidget.keyPressEvent(self, event)
 
     def reload(self, keepUiStates=True):
@@ -426,7 +450,7 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
         if isModule:
             headingCount = len(startDirOrModule) + 1
             heading = startDirOrModule + "."
-        
+
         testCount = 0
         for test in self._testManager.iterAllTestIds():
             testCount = testCount + 1
@@ -467,13 +491,15 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
                 )
                 self._setItemIconState(packageItem, constants.TEST_RESULT_NONE)
                 packageItem = packageItem.parent()
-        
-        self._uiStream.write("\n{}\n".format("-"*20))
+
+        self._uiStream.write("\n{}\n".format("-" * 20))
         if not self._testManager.hasLastListerError():
             self._uiStream.write("{} tests collected.\n\n".format(testCount))
         else:
             with self._uiStream.resultCtx(constants.TEST_RESULT_ERROR):
-                msg = "Error collecting tests from {}.\n\n".format(self._testManager.startDirOrModule())
+                msg = "Error collecting tests from {}.\n\n".format(
+                    self._testManager.startDirOrModule()
+                )
                 self._uiStream.write(msg)
 
         if keepUiStates:
@@ -523,7 +549,7 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
             item = self._findItemById(testId)
             if not item:
                 continue
-            
+
             self._calculateAncestorItemStates(item.parent(), updatedIds)
             if self._testManager.lastFailedTestId() == testId:
                 lastFailedItem = item
@@ -570,7 +596,7 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
         for item in self._iterSelectedSuiteOrTestCaseItems():
             if self._categoryOfItem(item) == constants.ITEM_CATEGORY_TEST:
                 return item
-            
+
             for i in range(item.childCount()):
                 return item.child(i)
 
@@ -623,7 +649,9 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
         self._goToCodeAct.triggered.connect(self._atGoToCode)
 
         self._reloadModulesAct = QtWidgets.QAction("Reload Selected Modules", self)
-        self._reloadModulesAct.setVisible(importutils.isReimportFeatureAvailable(silentCheck=True))
+        self._reloadModulesAct.setVisible(
+            importutils.isReimportFeatureAvailable(silentCheck=True)
+        )
         self._reloadModulesAct.triggered.connect(self._atReloadSelectedModules)
         self._reloadModulesAct.setIcon(self._reimportAndRunIcon)
 
@@ -715,3 +743,6 @@ class UnitTestTreeView(QtWidgets.QTreeWidget):
             act.triggered.connect(self._setSelectedItemsLevel)
 
         self._contextMenu.exec_(event.globalPos())
+
+    def _onGoToCodeError(self, msg):
+        uiutils.popUpMessageOnCursorPos(msg, self)
